# About Admin

Manage users, groups and authorizations and monitor activity.

Written by [Dynamic Solutions](https://www.dynamic-solutions.com).


## Change Log

* 2017-04-18 - Initial Release
* 2017-04-27 - Added logging
* 2017-07-14 - Implemented overview page
